@@ -130,7 +130,7 @@ static int basic_print_opt(const struct filter_util *qu, FILE *f,
 
 	if (tb[TCA_BASIC_POLICE]) {
 		print_nl();
-		tc_print_police(f, tb[TCA_BASIC_POLICE]);
+		tc_print_police(tb[TCA_BASIC_POLICE]);
 	}
 
 	if (tb[TCA_BASIC_ACT]) {
